Dynamically returns the names of all optimizer types with registered `step.*` methods.

list_simlr_optimizers(torch = FALSE)

Arguments

torch

Logical; if TRUE, returns a predefined list of optimizers compatible with torch.

Value

A character vector of optimizer names (e.g., "adam", "nadam", etc.)