renderSurfaceFunction.RdWill use rgl to render a substrate (e.g. anatomical) and overlay image (e.g. functional).
renderSurfaceFunction( surfimg, funcimg, surfval = 0.5, basefval, offsetfval, smoothsval = 0, smoothfval = 0, blobrender = TRUE, alphasurf = 1, alphafunc = 1, outdir = "./", outfn = NA, mycol, physical = TRUE, movieDuration = 6, zoom = 1.1 )
| surfimg | Input image to use as rendering substrate. |
|---|---|
| funcimg | Input list of images to use as functional overlays. |
| surfval | intensity level that defines isosurface |
| basefval | intensity level that defines lower threshold for functional image |
| offsetfval | intensity level that defines upper threshold for functional image |
| smoothsval | smoothing for the surface image |
| smoothfval | smoothing for the functional image |
| blobrender | render a blob as opposed to a surface patch |
| alphasurf | alpha for the surface contour |
| alphafunc | alpha value for functional blobs |
| outdir | output directory |
| outfn | output file name |
| mycol | name of color or colors |
| physical | boolean |
| movieDuration | in seconds |
| zoom | magnification factor |
0 -- Success
1 -- Failure