Low frequency, spatial varying simulated random bias field using random points and B-spline fitting.

simulateBiasField(
  domainImage,
  numberOfPoints = 10,
  sdBiasField = 1,
  numberOfFittingLevels = 4,
  meshSize = 1
)

Arguments

domainImage

image to define the spatial domain of the bias field.

numberOfPoints

number of randomly defined points to define the bias field (default = 10).

sdBiasField

characterize the standard deviation of the amplitude (default = 1).

numberOfFittingLevels

B-spline fitting parameter.

meshSize

B-spline fitting parameter (scalar or vector of size image dimension).

Value

simulated bias field

Author

Tustison NJ

Examples


library( ANTsR )
image <- antsImageRead( getANTsRData( "r16" ) )
logField <- simulateBiasField(image, numberOfPoints = 10, sdBiasField = 1.0,
   numberOfFittingLevels = 2, meshSize = 10 ) %>% iMath( "Normalize" )
logField <- ( exp( logField ) )^4
image <- image * logField
rm(image); gc()
#>           used  (Mb) gc trigger  (Mb) limit (Mb) max used  (Mb)
#> Ncells 4298838 229.6    6338411 338.6         NA  6338411 338.6
#> Vcells 7277715  55.6   26500152 202.2     102400 26500149 202.2
rm(logField); gc()
#>           used  (Mb) gc trigger  (Mb) limit (Mb) max used  (Mb)
#> Ncells 4298641 229.6    6338411 338.6         NA  6338411 338.6
#> Vcells 7277431  55.6   26500152 202.2     102400 26500149 202.2